// gpio.c
// Desenvolvido para a placa EK-TM4C1294XL
// Inicializa as portas J e N
// Prof. Guilherme Peron
// Prof. DaLuz - 2022/1S

#include <stdint.h>
#include "tm4c1294ncpdt.h"
  
#define GPIO_PORTJ  (0x0100) //bit 8
#define GPIO_PORTN  (0x1000) //bit 12

// -------------------------------------------------------------------------------
// Funo GPIO_Init
// Inicializa os ports J e N
// Parmetro de entrada: No tem
// Parmetro de sada: No tem
void GPIO_Init(void)
{
//1a. Ativar o clock para a porta setando o bit correspondente no registrador RCGCGPIO
SYSCTL_RCGCGPIO_R = (GPIO_PORTJ | GPIO_PORTN);
//1b.   aps isso verificar no PRGPIO se a porta est pronta para uso.
while((SYSCTL_PRGPIO_R & (GPIO_PORTJ | GPIO_PORTN) ) != (GPIO_PORTJ | GPIO_PORTN) ){};
// 2. Limpar o AMSEL para desabilitar a analgica
GPIO_PORTJ_AHB_AMSEL_R = 0x00;
GPIO_PORTN_AMSEL_R = 0x00;
// 3. Limpar PCTL para selecionar o GPIO
GPIO_PORTJ_AHB_PCTL_R = 0x00;
GPIO_PORTN_PCTL_R = 0x00;
// 4. DIR para 0 se for entrada, 1 se for sada
GPIO_PORTJ_AHB_DIR_R = 0x00;
GPIO_PORTN_DIR_R = 0x03;						//BIT0 | BIT1
// 5. Limpar os bits AFSEL para 0 para selecionar GPIO sem funo alternativa	
GPIO_PORTJ_AHB_AFSEL_R = 0x00;
GPIO_PORTN_AFSEL_R = 0x00; 
// 6. Setar os bits de DEN para habilitar I/O digital	
GPIO_PORTJ_AHB_DEN_R = 0x03;			//Bit0 e bit1
GPIO_PORTN_DEN_R = 0x03;					//Bit0 e bit1
// 7. Habilitar resistor de pull-up interno, setar PUR para 1
GPIO_PORTJ_AHB_PUR_R = 0x03;			//Bit0 e bit1	
}	

// -------------------------------------------------------------------------------
// Funo PortJ_Input
// L os valores de entrada do port J
// Parmetro de entrada: No tem
// Parmetro de sada: o valor da leitura do port
uint32_t PortJ_Input(void)
{
return GPIO_PORTJ_AHB_DATA_R;
}

// -------------------------------------------------------------------------------
// Funo PortN_Output
// Escreve os valores no port N
// Parmetro de entrada: Valor a ser escrito
// Parmetro de sada: no tem
void PortN_Output(uint32_t valor)
{
uint32_t temp;
//vamos zerar somente os bits menos significativos
//para uma escrita amigvel nos bits 0 e 1
temp = GPIO_PORTN_DATA_R & 0xFC;
//agora vamos fazer o OR com o valor recebido na funo
temp = temp | valor;
GPIO_PORTN_DATA_R = temp; 
}
